pitchtools.is_harmonic_diatonic_interval_abbreviation
=====================================================

.. autofunction:: abjad.tools.pitchtools.is_harmonic_diatonic_interval_abbreviation.is_harmonic_diatonic_interval_abbreviation
